# Column Qualifiers 

You can find [an introduction to Column Qualifiers](https://pdpipe.readthedocs.io/en/latest/starting/cq/) in our Getting Started section.

[An Introduction to Column Qualifiers :fontawesome-brands-leanpub:](https://pdpipe.readthedocs.io/en/latest/starting/cq/){ .md-button .md-button--primary}

::: pdpipe.cq
